@testset "ImpulseResponse" begin
    df = exampledata(:gk)
    ns = (:logcpi, :logip, :ff, :ebp, :ff4_tc)
    r = lp(df, :ebp, wnames=ns, nlag=12, nhorz=48, vce=HRVCE())
    f = irf(r, :ebp, :ff4_tc, lag=1)

    @test sprint(show, f) == "ImpulseResponse"
    w = VERSION < v"1.4.0" ? " " : ""
    @test sprint(show, MIME("text/plain"), f, context=:displaysize=>(15,80)) == """
        ImpulseResponse with 48 horizons:
        ────────────────────────────────────────────────────────────────
             Estimate  Std. Error      z  Pr(>|z|)  Lower 90%  Upper 90%
        ────────────────────────────────────────────────────────────────
        0   0.394494     0.473835   0.83    0.4051  -0.384894   1.17388$w
        1   0.161872     0.509504   0.32    0.7507  -0.676188   0.999932
        2  -0.0203338    0.611236  -0.03    0.9735  -1.02573    0.98506$w
        3   0.152802     0.724653   0.21    0.8330  -1.03915    1.34475$w
        4   0.147288     0.737092   0.20    0.8416  -1.06512    1.3597$w$w
        5   1.0421       0.771451   1.35    0.1768  -0.226826   2.31102$w
        ────────────────────────────────────────────────────────────────
        42 rows of estimates omitted"""

    r1 = lp(df, :ebp, wnames=ns, nlag=12, minhorz=1, nhorz=5, vce=HRVCE())
    f1 = irf(r1, :ebp, :ff4_tc, lag=1)
    @test sprint(show, MIME("text/plain"), f1) == """
        ImpulseResponse with 5 horizons:
        ────────────────────────────────────────────────────────────────
             Estimate  Std. Error      z  Pr(>|z|)  Lower 90%  Upper 90%
        ────────────────────────────────────────────────────────────────
        1   0.161872     0.509504   0.32    0.7507  -0.676188   0.999932
        2  -0.0203338    0.611236  -0.03    0.9735  -1.02573    0.98506$w
        3   0.152802     0.724653   0.21    0.8330  -1.03915    1.34475$w
        4   0.147288     0.737092   0.20    0.8416  -1.06512    1.3597$w$w
        5   1.0421       0.771451   1.35    0.1768  -0.226826   2.31102$w
        ────────────────────────────────────────────────────────────────"""

    @test sprint(show, MIME("text/plain"), coeftable(f1, level=0.95)) == """
        ────────────────────────────────────────────────────────────────
             Estimate  Std. Error      z  Pr(>|z|)  Lower 95%  Upper 95%
        ────────────────────────────────────────────────────────────────
        1   0.161872     0.509504   0.32    0.7507  -0.836738    1.16048
        2  -0.0203338    0.611236  -0.03    0.9735  -1.21833     1.17767
        3   0.152802     0.724653   0.21    0.8330  -1.26749     1.5731$w
        4   0.147288     0.737092   0.20    0.8416  -1.29739     1.59196
        5   1.0421       0.771451   1.35    0.1768  -0.469918    2.55411
        ────────────────────────────────────────────────────────────────"""

    est = SmoothLP(:ff4_tc, search=grid(10), criterion=GCV())
    r2 = lp(est, df, :ebp, xnames=:ff4_tc, wnames=ns, nlag=12, minhorz=1, nhorz=5, vce=HARVCE(EWC()))
    f2 = irf(r2, :ebp, :ff4_tc)
    @test sprint(show, MIME("text/plain"), f2) == """
        ImpulseResponse with 5 horizons:
        ──────────────────────────────────────────────────────────────
           Estimate  Std. Error     z  Pr(>|z|)   Lower 90%  Upper 90%
        ──────────────────────────────────────────────────────────────
        1  0.657581    0.208515  3.15    0.0061   0.293537     1.02162
        2  0.870131    0.213599  4.07    0.0009   0.497212     1.24305
        3  0.948191    0.274859  3.45    0.0033   0.468319     1.42806
        4  0.892463    0.255986  3.49    0.0031   0.445541     1.33939
        5  0.703113    0.44229   1.59    0.1315  -0.0690743    1.4753$w
        ──────────────────────────────────────────────────────────────"""
end
